==> haskell-tdigest-0.3.1-119-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tdigest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tdigest
version:              0.3.1
visibility:           public
id:                   tdigest-0.3.1-F4FEzzQxyQmCaqe7F1FmDm
key:                  tdigest-0.3.1-F4FEzzQxyQmCaqe7F1FmDm
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/haskell-tdigest#readme
synopsis:             On-line accumulation of rank-based statistics
description:
    A new data structure for accurate on-line accumulation of rank-based statistics such as quantiles and trimmed means.

    See original paper: "Computing extremely accurate quantiles using t-digest" by Ted Dunning and Otmar Ertl
    for more details <https://github.com/tdunning/t-digest/blob/07b8f2ca2be8d0a9f04df2feadad5ddc1bb73c88/docs/t-digest-paper/histo.pdf>.

category:             Numeric
abi:                  c91eb98d2d5aa1e8b540efd7122121ea
exposed:              True
exposed-modules:
    Data.TDigest Data.TDigest.Internal Data.TDigest.NonEmpty
    Data.TDigest.Postprocess Data.TDigest.Postprocess.Internal
    Data.TDigest.Tree Data.TDigest.Tree.Internal
    Data.TDigest.Tree.NonEmpty Data.TDigest.Tree.Postprocess
    Data.TDigest.Vector Data.TDigest.Vector.Internal
    Data.TDigest.Vector.NonEmpty Data.TDigest.Vector.Postprocess

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tdigest-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tdigest-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tdigest-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tdigest
hs-libraries:         HStdigest-0.3.1-F4FEzzQxyQmCaqe7F1FmDm
depends:
    base-4.17.2.1 binary-0.8.9.1 deepseq-1.4.8.0
    foldable1-classes-compat-0.1.2-5rko4Azb7rz1b3j7UY7lyg
    reducers-3.12.5-2SrNk3rYyef97Ats6BVZjQ transformers-0.5.6.2
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57
    vector-algorithms-0.9.1.0-EhwKZ2FrR67GHUoPSU38UJ

haddock-interfaces:   /usr/share/doc/haskell-tdigest/html/tdigest.haddock
haddock-html:         /usr/share/doc/haskell-tdigest/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tdigest-0.3.1-139-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tdigest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tdigest
version:              0.3.1
visibility:           public
id:                   tdigest-0.3.1-3cbfeF5HUzPKmTQSOcrdDY
key:                  tdigest-0.3.1-3cbfeF5HUzPKmTQSOcrdDY
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/haskell-tdigest#readme
synopsis:             On-line accumulation of rank-based statistics
description:
    A new data structure for accurate on-line accumulation of rank-based statistics such as quantiles and trimmed means.

    See original paper: "Computing extremely accurate quantiles using t-digest" by Ted Dunning and Otmar Ertl
    for more details <https://github.com/tdunning/t-digest/blob/07b8f2ca2be8d0a9f04df2feadad5ddc1bb73c88/docs/t-digest-paper/histo.pdf>.

category:             Numeric
abi:                  e6524783008ecdc9f944914b111d415a
exposed:              True
exposed-modules:
    Data.TDigest Data.TDigest.Internal Data.TDigest.NonEmpty
    Data.TDigest.Postprocess Data.TDigest.Postprocess.Internal
    Data.TDigest.Tree Data.TDigest.Tree.Internal
    Data.TDigest.Tree.NonEmpty Data.TDigest.Tree.Postprocess
    Data.TDigest.Vector Data.TDigest.Vector.Internal
    Data.TDigest.Vector.NonEmpty Data.TDigest.Vector.Postprocess

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tdigest-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tdigest-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tdigest-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tdigest
hs-libraries:         HStdigest-0.3.1-3cbfeF5HUzPKmTQSOcrdDY
depends:
    base-4.17.2.1 binary-0.8.9.1 deepseq-1.4.8.0
    foldable1-classes-compat-0.1.2-6CnG8XigcKeJl7zPbqkq1N
    reducers-3.12.5-820cDb4znE9Cq21cO3kAUK transformers-0.5.6.2
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS
    vector-algorithms-0.9.1.0-E6Re4BGH6W6AUhX7AjtMtV

haddock-interfaces:   /usr/share/doc/haskell-tdigest/html/tdigest.haddock
haddock-html:         /usr/share/doc/haskell-tdigest/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
